==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/testng/src/org/netbeans/modules/testng/spi/TestConfig.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright © 2008-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */
package org.netbeans.modules.testng.spi;

import org.netbeans.modules.testng.actions.TestConfigAccessor;
import org.openide.filesystems.FileObject;

/**
 *
 * @author lukas
 */
public final class TestConfig {

    private final boolean rerun;
    private final String pkgName;
    private final String className;
    private final String methodName;
    private final FileObject test;


    static {
        TestConfigAccessor.setDefault(new TestConfigAccessor() {

            @Override
            public TestConfig createTestConfig(FileObject test, boolean rerun, String pkgName, String className, String methodName) {
                return new TestConfig(test, rerun, pkgName, className, methodName);
            }
        });
    }

    private TestConfig(FileObject test, boolean rerun, String pkgName, String className, String methodName) {
        this.test = test;
        this.rerun = rerun;
        this.pkgName = pkgName;
        this.className = className;
        this.methodName = methodName;
    }

    public String getClassName() {
        return className;
    }

    public String getMethodName() {
        return methodName;
    }

    public String getPackageName() {
        return pkgName;
    }

    public boolean doRerun() {
        return rerun;
    }

    public FileObject getTest() {
        return test;
    }
}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/testng/src/org/netbeans/modules/testng/spi/TestConfig.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright © 2008-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */
package org.netbeans.modules.testng.spi;

import org.netbeans.modules.testng.TestConfigAccessor;
import org.openide.filesystems.FileObject;

/**
 *
 * @author lukas
 */
public final class TestConfig {

    private final boolean rerun;
    private final String pkgName;
    private final String className;
    private final String methodName;
    private final FileObject test;


    static {
        TestConfigAccessor.setDefault(new TestConfigAccessor() {

            @Override
            public TestConfig createTestConfig(FileObject test, boolean rerun, String pkgName, String className, String methodName) {
                return new TestConfig(test, rerun, pkgName, className, methodName);
            }
        });
    }

    private TestConfig(FileObject test, boolean rerun, String pkgName, String className, String methodName) {
        this.test = test;
        this.rerun = rerun;
        this.pkgName = pkgName;
        this.className = className;
        this.methodName = methodName;
    }

    public String getClassName() {
        return className;
    }

    public String getMethodName() {
        return methodName;
    }

    public String getPackageName() {
        return pkgName;
    }

    public boolean doRerun() {
        return rerun;
    }

    public FileObject getTest() {
        return test;
    }
}
